====
clru
====
.. image:: https://img.shields.io/pypi/v/clru.svg
        :target: https://pypi.python.org/pypi/clru

.. image:: https://img.shields.io/travis/klaussfreire/clru.svg
        :target: https://travis-ci.org/klaussfreire/clru

.. image:: https://readthedocs.org/projects/clru/badge/?version=latest
        :target: https://clru.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Cython LRU Structures

* Free software: GNU LESSER GENERAL PUBLIC LICENSE v3
* Documentation: https://clru.readthedocs.io.

Features
========

* TODO



Release
=======

- Update the changelog release date on `CHANGELOG <CHANGELOG.rst>`__
- Commit the changes to master (there is no need to do an PR in this case)

  .. code-block:: console

      $ git commit CHANGELOG -m 'New release'


Credits
=======

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
